extern crate dirs;
extern crate inotify;

use dirs::home_dir;
use inotify::{Inotify, WatchMask};
use std::process::Command;

fn main() {
    let mut inotify = Inotify::init().expect("Failed to initialise inotify.");

    let home = home_dir().expect("Failed to find home directory.");

    // Watch for modify and close events.
    inotify
        .add_watch(
            format!("{}/.config/systemd/user/", home.display()),
            WatchMask::CREATE | WatchMask::DELETE | WatchMask::CLOSE_WRITE | WatchMask::MOVE,
        )
        .expect("Failed to add file watch");

    let _ = sd_notify::notify(true, &[sd_notify::NotifyState::Ready]);

    let mut buffer = [0u8; 4096];
    loop {
        inotify
            .read_events_blocking(&mut buffer)
            .expect("Failed to read inotify events");

        let output = Command::new("systemctl")
            .args(&["--user", "daemon-reload"])
            .output()
            .expect("Failed to reload systemd units");

        println!("Reload done, {}.", output.status);
    }
}
